@@ -42,7 +42,8 @@ md_delete_verify() {
 				echo ${DEV} >> /var/log/mdcfg.log
 			done
 			;;
-		"false") ;;
+		"false")
+			: ;;
 	esac
 }
 
@@ -62,8 +63,9 @@ md_delete() {
 
 	case $RET in
 		md*)
-			md_delete_verify $RET;;
-		*);;
+			md_delete_verify $RET ;;
+		*)
+			: ;;
 	esac
 }
 
@@ -73,16 +75,20 @@ md_createmain() {
 	db_go
 	if [ $? -ne "30" ]; then
 		db_get mdcfg/createmain
+		if [ "$RET" = Cancel ]; then
+			return
+		fi
+		RAID_SEL="$RET"
 		
 		get_partitions
 
-		case $RET in
+		case "$RAID_SEL" in
 			"RAID5")
-			md_create_raid5;;
+				md_create_raid5 ;;
 			"RAID1")
-			md_create_raid1;;
+				md_create_raid1 ;;
 			"RAID0")
-			md_create_raid0;;
+				md_create_raid0 ;;
 		esac
 	fi
 }
@@ -100,16 +106,17 @@ get_partitions() {
 	NUM_PART=0
 	for i in ${RAW_PARTITIONS}; do
 		DEV=`echo ${i}|sed -e "s/\/dev\///"`
-		MAPPEDDEV=`mapdevfs ${i} | sed -e "s/\/dev\///"`
+		REALDEV=$(mapdevfs "$i")
+		MAPPEDDEV=$(echo "$REALDEV" | sed -e "s/\/dev\///")
 
 		if grep -q "\(${DEV}\|${MAPPEDDEV}\)" /proc/mdstat; then
 			continue
 		fi
 
 		if [ -z "${PARTITIONS}" ] ; then
-			PARTITIONS="${i}"
+			PARTITIONS="$REALDEV"
 		else
-			PARTITIONS="${PARTITIONS}, ${i}"
+			PARTITIONS="${PARTITIONS}, $REALDEV"
 		fi
 		NUM_PART=$(($NUM_PART + 1))
 	done
@@ -169,11 +176,12 @@ md_create_raid0() {
 		let MD_NUM++
 	fi
 
-	echo "Number of devices in the RAID0 array md${MD_NUM}: ${SELECTED}"
+	logger -t mdcfg "Number of devices in the RAID0 array md${MD_NUM}: ${SELECTED}"
 
 	RAID_DEVICES="$(echo ${RET} | sed -e 's/,//g')"
-	echo "Commandline:"
-	`mdadm --create /dev/md/${MD_NUM} --auto=yes --force -R -l raid0 -n ${SELECTED} ${RAID_DEVICES}`
+	log-output -t mdcfg \
+		mdadm --create /dev/md/${MD_NUM} --auto=yes --force -R -l raid0 \
+		      -n ${SELECTED} ${RAID_DEVICES}
 }
 
 md_create_raid1() {
@@ -305,11 +313,13 @@ md_create_raid1() {
 		let MD_NUM++
 	fi
 
-	echo "Selected spare count: ${NAMED_SPARES}"
-	echo "Raid devices count: ${DEV_COUNT}"
-	echo "Spare devices count: ${SPARE_COUNT}"
-	echo "Commandline:"
-	`mdadm --create /dev/md/${MD_NUM} --auto=yes --force -R -l raid1 -n ${DEV_COUNT} -x ${SPARE_COUNT} ${RAID_DEVICES} ${MISSING_DEVICES} ${SPARE_DEVICES} ${MISSING_SPARES}`
+	logger -t mdcfg "Selected spare count: ${NAMED_SPARES}"
+	logger -t mdcfg "Raid devices count: ${DEV_COUNT}"
+	logger -t mdcfg "Spare devices count: ${SPARE_COUNT}"
+	log-output -t mdcfg \
+		mdadm --create /dev/md/${MD_NUM} --auto=yes --force -R -l raid1 \
+		      -n ${DEV_COUNT} -x ${SPARE_COUNT} ${RAID_DEVICES} ${MISSING_DEVICES} \
+		      ${SPARE_DEVICES} ${MISSING_SPARES}
 }
 
 md_create_raid5() {
@@ -445,11 +455,13 @@ md_create_raid5() {
 		let MD_NUM++
 	fi
 
-	echo "Selected spare count: ${NAMED_SPARES}"
-	echo "Raid devices count: ${DEV_COUNT}"
-	echo "Spare devices count: ${SPARE_COUNT}"
-	echo "Commandline:"
-	`mdadm --create /dev/md/${MD_NUM} --auto=yes --force -R -l raid5 -n ${DEV_COUNT} -x ${SPARE_COUNT} ${RAID_DEVICES} ${SPARE_DEVICES} ${MISSING_SPARES}`
+	logger -t mdcfg "Selected spare count: ${NAMED_SPARES}"
+	logger -t mdcfg "Raid devices count: ${DEV_COUNT}"
+	logger -t mdcfg "Spare devices count: ${SPARE_COUNT}"
+	log-output -t mdcfg \
+		mdadm --create /dev/md/${MD_NUM} --auto=yes --force -R -l raid5 \
+		      -n ${DEV_COUNT} -x ${SPARE_COUNT} ${RAID_DEVICES} \
+		      ${SPARE_DEVICES} ${MISSING_SPARES}
 }
 
 md_mainmenu() {
@@ -463,11 +475,11 @@ md_mainmenu() {
 		db_get mdcfg/mainmenu
 		case $RET in
 			"Create MD device")
-				md_createmain;;
+				md_createmain ;;
 			"Delete MD device")
-				md_delete;;
+				md_delete ;;
 			"Finish")
-				break;;
+				break ;;
 		esac
 	done
 }
@@ -484,14 +496,13 @@ modprobe raid5 >/dev/null 2>&1
 mkdir -p /dev/md
 
 # Try to detect MD devices, and start them
-/sbin/mdrun
+mdrun
 
 # Make sure that we have md-support
 if [ ! -e /proc/mdstat ]; then
 	db_set mdcfg/nomd "false"
 	db_input high mdcfg/nomd
 	db_go
-	db_stop
 	exit 0
 fi
 
@@ -503,5 +514,4 @@ apt-install mdadm
 
 md_mainmenu
 
-#db_stop
 exit 0
